@@ -1032,10 +1032,15 @@ void qsynthMainForm::stdoutNotifySlot ( int fd )
 
 
 // Stdout buffer handler -- now splitted by complete new-lines...
-void qsynthMainForm::appendStdoutBuffer ( const QString& sText )
+void qsynthMainForm::appendStdoutBuffer ( const QString& s )
 {
-	m_sStdoutBuffer.append(sText);
+	m_sStdoutBuffer.append(s);
 
+	processStdoutBuffer();
+}
+
+void qsynthMainForm::processStdoutBuffer (void)
+{
 	const int iLength = m_sStdoutBuffer.lastIndexOf('\n');
 	if (iLength > 0) {
 		const QString& sTemp = m_sStdoutBuffer.left(iLength);
@@ -1052,51 +1057,50 @@ void qsynthMainForm::appendStdoutBuffer ( const QString& sText )
 void qsynthMainForm::flushStdoutBuffer (void)
 {
 	if (!m_sStdoutBuffer.isEmpty()) {
-		appendMessagesText(m_sStdoutBuffer);
-		m_sStdoutBuffer.truncate(0);
+		processStdoutBuffer();
+		m_sStdoutBuffer.clear();
 	}
 }
 
 
 // Messages output methods.
-void qsynthMainForm::appendMessages( const QString& sText )
+void qsynthMainForm::appendMessages ( const QString& s )
 {
 	if (m_pMessagesForm)
-		m_pMessagesForm->appendMessages(sText);
+		m_pMessagesForm->appendMessages(s);
 }
 
 
-void qsynthMainForm::appendMessagesColor(
-	const QString& sText, const QString& sColor )
+void qsynthMainForm::appendMessagesColor ( const QString& s, const QColor& rgb )
 {
 	if (m_pMessagesForm)
-		m_pMessagesForm->appendMessagesColor(sText, sColor);
+		m_pMessagesForm->appendMessagesColor(s, rgb);
 }
 
 
-void qsynthMainForm::appendMessagesText( const QString& sText )
+void qsynthMainForm::appendMessagesText ( const QString& s )
 {
 	if (m_pMessagesForm)
-		m_pMessagesForm->appendMessagesText(sText);
+		m_pMessagesForm->appendMessagesText(s);
 }
 
 
-void qsynthMainForm::appendMessagesError( const QString& sText )
+void qsynthMainForm::appendMessagesError ( const QString& s )
 {
 	if (m_pMessagesForm)
 		m_pMessagesForm->show();
 
-	appendMessagesColor(sText.simplified(), "#ff0000");
+	appendMessagesColor(s.simplified(), Qt::red);
 
 	const QString& sTitle = tr("Error");
 #ifdef CONFIG_SYSTEM_TRAY
 	if (m_pOptions->bSystemTray && m_pSystemTray
 		&& QSystemTrayIcon::supportsMessages()) {
-		m_pSystemTray->showMessage(sTitle, sText, QSystemTrayIcon::Critical);
+		m_pSystemTray->showMessage(sTitle, s, QSystemTrayIcon::Critical);
 	}
 	else
 #endif
-	QMessageBox::critical(this, sTitle, sText, QMessageBox::Cancel);
+	QMessageBox::critical(this, sTitle, s, QMessageBox::Cancel);
 }
 
 
@@ -1505,18 +1509,11 @@ void qsynthMainForm::toggleMainForm (void)
 
 	m_pOptions->saveWidgetGeometry(this, true);
 
-	if (isVisible() && !isMinimized()) {
+	if (isVisible() && !isMinimized() && isActiveWindow()) {
 	#ifdef CONFIG_SYSTEM_TRAY
-		if (m_pOptions->bSystemTray && m_pSystemTray) {
-			// Hide away from sight, if not active...
-			if (isActiveWindow()) {
-				hide();
-			} else {
-				showNormal();
-				raise();
-				activateWindow();
-			}
-		}
+		// Hide away from sight, totally...
+		if (m_pOptions->bSystemTray && m_pSystemTray)
+			hide();
 		else
 	#endif
 		// Minimize (iconify) normally.
@@ -1598,41 +1595,17 @@ void qsynthMainForm::showOptionsForm (void)
 		const QString sOldMessagesLogPath = m_pOptions->sMessagesLogPath;
 		const QString sOldMessagesFont = m_pOptions->sMessagesFont;
 	#ifdef CONFIG_SYSTEM_TRAY
-		const bool    bOldSystemTray    = m_pOptions->bSystemTray;
+		const bool    bOldSystemTray = m_pOptions->bSystemTray;
 	#endif
-		const bool    bOldOutputMeters  = m_pOptions->bOutputMeters;
-		const bool    bOldStdoutCapture = m_pOptions->bStdoutCapture;
-		const bool    bOldKeepOnTop     = m_pOptions->bKeepOnTop;
-		const int     iOldBaseFontSize  = m_pOptions->iBaseFontSize;
+		const bool    bOldOutputMeters = m_pOptions->bOutputMeters;
 		const int     bOldMessagesLimit = m_pOptions->bMessagesLimit;
 		const int     iOldMessagesLimitLines = m_pOptions->iMessagesLimitLines;
-		const int     iOldKnobStyle     = m_pOptions->iKnobStyle;
-		const int     iOldKnobMotion    = m_pOptions->iKnobMotion;
+		const int     iOldKnobStyle  = m_pOptions->iKnobStyle;
+		const int     iOldKnobMotion = m_pOptions->iKnobMotion;
 		// Load the current setup settings.
 		pOptionsForm->setup(m_pOptions);
 		// Show the setup dialog...
 		if (pOptionsForm->exec()) {
-			// Warn if something will be only effective on next run.
-			if (( bOldStdoutCapture && !m_pOptions->bStdoutCapture) ||
-				(!bOldStdoutCapture &&  m_pOptions->bStdoutCapture) ||
-				( bOldKeepOnTop     && !m_pOptions->bKeepOnTop)     ||
-				(!bOldKeepOnTop     &&  m_pOptions->bKeepOnTop)     ||
-				(iOldBaseFontSize != m_pOptions->iBaseFontSize)) {
-				const QString& sTitle
-					= tr("Information");
-				const QString& sText
-					= tr("Some settings will be only effective\n"
-						"next time you start this program.");
-			#ifdef CONFIG_SYSTEM_TRAY
-				if (m_pOptions->bSystemTray && m_pSystemTray
-					&& QSystemTrayIcon::supportsMessages()) {
-					m_pSystemTray->showMessage(
-						sTitle, sText, QSystemTrayIcon::Information);
-				}
-				else
-			#endif
-				QMessageBox::information(this, sTitle, sText);
-			}
 			// Check wheather something immediate has changed.
 			if (( bOldMessagesLog && !m_pOptions->bMessagesLog) ||
 				(!bOldMessagesLog &&  m_pOptions->bMessagesLog) ||
